module Api
  module V1
    class CitizensController < ApplicationController
      protect_from_forgery with: :null_session
      respond_to :json

      before_action :api_authenticate, except: :create

      def create
        Citizen.create(citizen_params)
        render json: {}, status: :created
      end

      def index
        @citizens = Citizen.all
      end

      def show
        @citizen = Citizen.find_by(id: params[:id])
        if @citizen.nil?
          render json: {}, status: :not_found
        else
          render @citizen
        end
      end

      private

        def citizen_params
          params.require(:citizen).permit(:name, :login, :password,
            :password_confirmation)
        end

        def api_authenticate
          authenticate_or_request_with_http_token do |token, options|
            @citizen = Citizen.where(remember_token: Citizen.digest(token)).first
          end
        end
    end
  end
end