module Api
  module V1
    class PostsController < ApplicationController
      protect_from_forgery with: :null_session
      respond_to :json

      before_action :api_authenticate

      def show
        @post = Post.find(params[:id])
        if @post.nil?
          render json: {}, status: :not_found
        else
          render @post
        end
      end

      def index
        @posts = Post.all
      end

      def create
        @post = Post.create(post_params)
        render json: { id: @post.id }, status: :created
      end

      def update
        @post = Post.find_by(id: params[:id])

        begin
          if @post.toggle!(:closed)
            render json: { id: @post.id, closed: @post.closed? }, status: :ok
          else
            render json: { id: @post.id }, status: :unprocessable_entity
          end
        rescue
          render json: { id: @post.id }, status: :internal_server_error
        end
      end

      private

        def post_params
          params.require(:post).permit(:title, :body, :citizen_id)
        end

        def api_authenticate
          authenticate_or_request_with_http_token do |token, options|
            @citizen = Citizen.where(remember_token: Citizen.digest(token)).first
          end
        end
    end
  end
end