module Api
  module V1
    class SessionsController < ApplicationController
      protect_from_forgery with: :null_session
      respond_to :json

      before_action :api_authenticate, except: :create

      def create
        params.require(:session).permit(:name, :login)
        citizen = Citizen.find_by(login: params[:session][:login].downcase)
        if citizen && citizen.authenticate(params[:session][:password])
          sign_in_api citizen
          render json: { id: citizen.id, token: @remember_token }, status: :ok
        else
          render json: {}, status: :unauthorized
        end
      end

      def destroy
        citizen = Citizen.find_by(id: params[:id])
        if citizen.nil?
          render json: {}, status: :not_found
        else
          sign_out_api(citizen)
          render citizen
        end
      end

      private
        def sign_in_api(citizen)
          @remember_token = Citizen.new_remember_token
          citizen.update_attribute(:remember_token, Citizen.digest(@remember_token))
        end

        def sign_out_api(citizen)
          citizen.update_attribute(:remember_token, 
                                    Citizen.digest(Citizen.new_remember_token))
        end

        def api_authenticate
          authenticate_or_request_with_http_token do |token, options|
            @citizen = Citizen.where(remember_token: Citizen.digest(token)).first
          end
        end
    end
  end
end