class Citizen < ActiveRecord::Base
  has_many :posts
  has_many :comments

  # be sure to store login in downcase, in case the db index is case-insensitive
  before_save { self.login = login.downcase }
  before_create :create_remember_token

  validates :name, presence: true, length: { maximum: 50 }
  VALID_LOGIN_REGEX = /\A[\w+\-.]+@[a-z\d\-]+(?:\.[a-z\d\-]+)*\.[a-z]+\z/i
  validates :login, presence: true, format: { with: VALID_LOGIN_REGEX },
                    uniqueness: { case_sensitive: false }

  # this adds password, password_confirmation, the method authenticate
  # and all the validations. It expect a password_diggest attribute in the model
  has_secure_password
  validates :password, length: { minimum: 6 }

  def Citizen.new_remember_token
    SecureRandom.urlsafe_base64
  end

  def Citizen.digest(token)
    Digest::SHA1.hexdigest(token.to_s)
  end

  private

    def create_remember_token
      self.remember_token = Citizen.digest(Citizen.new_remember_token)
    end
end
