require 'spec_helper'

describe "Authentication" do

  subject { page }

  describe "signin page" do
    before { visit signin_path }

    it { should have_title('Identificarse') }
    it { should have_content('Identificarse') }
  end

  describe "signin" do
    before { visit signin_path }

    describe "with invalid information" do
      before { click_button "Entrar" }

      it { should have_title('Identificarse') }
      it { should have_selector('div.alert.alert-error') }

      # flash must dissapear if we change to another page
      describe "after visiting another page" do
        before { click_link "Inicio" }
        it { should_not have_selector('div.alert.alert-error') }
      end
    end

    describe "with valid information" do
      let(:admin) { FactoryGirl.create(:admin) }
      before { sign_in admin }

      it { should have_title('Inicio') }
      it { should have_link('Ciudadanos', href: citizens_path) }
      it { should have_link('Entradas', href: posts_path) }
      it { should have_link("Perfil (#{admin.name})", href: citizen_path(admin)) }
      it { should have_link('Cerrar sesión', href: signout_path) }
      it { should_not have_link('Identificarse', href: signin_path) }

      # we look for the correct link: Cerrar sesión/Identificarse
      describe "followed by signout" do
        before { click_link "Cerrar sesión" }
        it { should have_link "Identificarse" }
      end
    end

    describe "with non admin citizen" do
      let(:citizen) { FactoryGirl.create(:citizen) }
      before { sign_in citizen }

      it { should have_title('Identificarse') }
      it { should have_selector('div.alert.alert-error') }      
    end
  end

  describe "authorization" do
    let(:admin) { FactoryGirl.create(:admin) }

    describe "for non-signed-in citizens" do

      describe "in the Citizens controller" do
        before { visit citizens_path }
        it { should have_title('Identificarse') }
      end

      describe "in the Posts controller" do
        before { visit posts_path }
        it { should have_title('Identificarse') }
      end

      # test that we are doing a smart redirection
      describe "when attempting to visit a protected page" do
        before do
          visit citizens_path
          fill_in "Login", with: admin.login
          fill_in "Password", with: admin.password
          click_button "Entrar"
        end

        describe "after signin in" do
          it "should render the desired protected page" do
            expect(page).to have_title('Índice de ciudadanos')
          end
        end
      end

      describe "visiting a profile page" do
        before { visit citizen_path(admin) }
        it { should have_title('Identificarse') }
      end
    end

    describe "for signed-in citizens" do

      describe "in the Citizens controller" do
        before do
          sign_in admin
          visit citizens_path
        end

        it { should have_title('Índice de ciudadanos') }

        describe "view a single citizen" do
          before { visit citizen_path(admin) }

          it { should have_title(admin.name)}
        end
      end

      describe "in the Posts controller" do
         before do
          sign_in admin
          visit posts_path
        end

        it { should have_title('Índice de entradas') }

        describe "view a single post" do
          let(:post) { FactoryGirl.create(:post, citizen: admin) }
          before { visit post_path(post) }

          it { should have_title(post.title)}
        end
      end
    end
  end
end
