require 'spec_helper'

describe "CitizenPages" do

  subject { page }

  describe "index" do
    let(:admin) { FactoryGirl.create(:admin) }
    before(:each) do
      sign_in admin
      visit citizens_path
    end

    it { should have_title('Índice de ciudadanos') }
    it { should have_content('Índice de ciudadanos') }

    describe "pagination" do

      before(:all) { 30.times { FactoryGirl.create(:citizen) } }
      after(:all)  { Citizen.delete_all }

      it { should have_selector('div.pagination') }

      it "should list each citizen" do
        Citizen.paginate(page: 1) do |citizen|
          expect(page).to have_selector('li', text: citizen.name)
        end
      end
    end
  end

  describe "profile page" do
    let(:admin) { FactoryGirl.create(:admin) }
    let(:citizen) { FactoryGirl.create(:citizen) }
    let!(:p1) { FactoryGirl.create(:post, citizen: citizen, title: "Uno") }
    let!(:p2) { FactoryGirl.create(:post, citizen: citizen, title: "Dos") }

    before do
      sign_in admin
      visit citizen_path(citizen)
    end

    it { should have_content(citizen.name) }
    it { should have_title(citizen.name) }

    describe "posts" do
      it { should have_content(p1.title) }
      it { should have_content(p1.body) }
      it { should have_content(p2.title) }
      it { should have_content(p2.body) }
      it { should have_content(citizen.posts.count) }
    end
  end

=begin
  describe "signup page" do
    before { visit signup_path }

    it { should have_content('Registro') }
    it { should have_title(full_title('Registro')) }
  end
=end

end
