package org.masantamaria.socialpolis;

import android.support.v7.app.ActionBarActivity;
import android.support.v7.app.ActionBar;
import android.support.v4.app.Fragment;
import android.app.FragmentTransaction;
import android.os.Bundle;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Toast;
import android.os.Build;
import retrofit.Callback;
import retrofit.RetrofitError;
import retrofit.client.Response;

import org.masantamaria.socialpolis.api.SocialPolis;
import org.masantamaria.socialpolis.api.SocialPolisService;
import org.masantamaria.socialpolis.fragments.DashboardFragment;
import org.masantamaria.socialpolis.fragments.LoginFragment;
import org.masantamaria.socialpolis.fragments.NewAccountFragment;
import org.masantamaria.socialpolis.model.Citizen;
import org.masantamaria.socialpolis.model.SocialPolisToken;

public class MainActivity extends ActionBarActivity implements
		LoginFragment.OnLoginFragment, NewAccountFragment.OnNewAccountFragment,
		DashboardFragment.OnDashboardFragment {

	private SocialPolis api;
	private SocialPolisToken citizenToken;

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		if (savedInstanceState == null) {
			getSupportFragmentManager().beginTransaction()
					.add(R.id.container, new LoginFragment()).commit();
		}
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {

		// Inflate the menu; this adds items to the action bar if it is present.
		getMenuInflater().inflate(R.menu.login, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		// Handle action bar item clicks here. The action bar will
		// automatically handle clicks on the Home/Up button, so long
		// as you specify a parent activity in AndroidManifest.xml.
		int id = item.getItemId();
		if (id == R.id.action_settings) {
			return true;
		}
		return super.onOptionsItemSelected(item);
	}

	public SocialPolis getApi() {
		if (api == null) {
			api = SocialPolisService.getService();
		}
		return api;
	}

	public void setApi(SocialPolis socialpolisApi) {
		this.api = socialpolisApi;
	}

	/**
	 * Fragments callback methods
	 * 
	 */

	@Override
	public void onSignup() {
		// Change to the NewAccountFragment
		NewAccountFragment newFragment = new NewAccountFragment();
		changeToFragment(newFragment);
	}

	@Override
	public void onLogin(String login, String password) {
		if (login.equals("") || password.equals("")) {
			displayMessage(getString(R.string.empty_credentials_string));
		} else {
			// make the login
			Citizen citizen = new Citizen(login, password);
			getApi().login(citizen, loginCallback());
		}
	}

	private Callback<SocialPolisToken> loginCallback() {
		return new Callback<SocialPolisToken>() {

			@Override
			public void failure(RetrofitError retrofitError) {
				Response r = retrofitError.getResponse();
				if (r != null && r.getStatus() == 401) {
					displayMessage(getString(R.string.bad_credentials_string));
				} else {
					displayMessage(getString(R.string.comm_error_string));
				}
			}

			@Override
			public void success(SocialPolisToken socialpolisToken,
					Response response) {
				// displayMessage(socialpolisToken.getId() + ":" +
				// socialpolisToken.getToken());
				citizenToken = socialpolisToken;

				// Change to the DashboardFragment
				DashboardFragment dashboardFragment = new DashboardFragment();
				changeToFragment(dashboardFragment);
			}
		};
	}

	@Override
	public void onNewAccountCreate(String name, String login, String password,
			String passwordconfirm) {
		final Citizen citizen = new Citizen(login, name, password, passwordconfirm);
		getApi().createCitizen(citizen, new Callback<Response>() {

			@Override
			public void failure(RetrofitError retrofitError) {
				displayMessage(getString(R.string.comm_error_string));
			}

			@Override
			public void success(Response socialpolisResponse,
					Response response) {
				getApi().login(citizen,  loginCallback());
			}

		});
	}

	public void onMyEntries(View view) {
		displayMessage(getString(R.string.not_implemented_string));
	}

	public void onLogout(View view) {
		String headerToken = "Token token=" + citizenToken.getToken();
		getApi().logout(headerToken, new Callback<Citizen>() {

			@Override
			public void failure(RetrofitError retrofitError) {
				//displayMessage(getString(R.string.logout_error_string));
				citizenToken = null;

				// Change to the LoginFragment
				LoginFragment loginFragment = new LoginFragment();
				changeToFragment(loginFragment);
			}

			@Override
			public void success(Citizen citizen, Response response) {
				citizenToken = null;

				// Change to the LoginFragment
				LoginFragment loginFragment = new LoginFragment();
				changeToFragment(loginFragment);
			}
		});
	}
	
	@Override
	public void onNewEntry(View view) {
		displayMessage(getString(R.string.not_implemented_string));
	}

	@Override
	public void onSearch(View view) {
		displayMessage(getString(R.string.not_implemented_string));
	}

	/**
	 * Helper methods
	 * 
	 */

	private void displayMessage(String message) {
		Toast.makeText(MainActivity.this, message, Toast.LENGTH_LONG).show();
	}
	
	private void changeToFragment(Fragment fragment) {
		android.support.v4.app.FragmentTransaction transaction = getSupportFragmentManager()
				.beginTransaction();

		transaction.replace(R.id.container, fragment);
		transaction.addToBackStack(null);

		transaction.commit();
	}

}
